-- KNX Application Program Handler
-- URNs, IDs and COs in this file are specific to the AS2
--
-- Module with specific functions to AS2

local m = require("knxappprghandler_base")
local DPT = m.DPT

local channelTable = {
  {
    name = "GDS-Device-Channel",
    dps = {
      {
        name = "Ready",
        dpt = DPT(1, 11),
        rCo = 1,
        event = true
      },
      {
        name = "State",
        dpt = DPT(5, 10),
        rCo = 2,
        event = true
      },
      {
        name = "Local-Time", -- date
        dpt = DPT(11, 1),
        rCo = 6,
        internal = false
      },
      {
        name = "Local-Time", -- time
        dpt = DPT(10, 1),
        rCo = 7,
        internal = false
      },
      {
        name = "Uptime",
        dpt = DPT(13, 100),
        rCo = 8,
        event = true,
        internal = false
      }
    }
  },
  
  {
    name = "Alarm-Control-Unit",
    dps = {
      {
        name = "Configuration-Mode-State",
        dpt = DPT(1, 11),
        rCo = 1001,
        event = true,
        internal = false
      },
      {
        name = "Learn-Mode",
        dpt = DPT(1, 11),
        rCo = 1002,
        event = true,
        internal = false
      },
      {
        name = "Test-Run-State",
        dpt = DPT(1, 11),
        rCo = 1025,
        event = true,
        internal = false
      }
    }
  },

  {
    name = "KNX-Programming-Modes",
    dps = {
      {
        name = "Programming-Mode-Device-1",
        dpt = DPT(1, 1),
        wCo = 50,
        rCo = 51,
        event = true
      }
    }
  },

  {
    name = "Security-Area-{0}",
    count = 4,
    offset = 100,
    dps = {
      {
        name = "Arm-State",
        dpt = DPT(5, 10),
        rCo = 1101,
        event = true
      },
      {
        name = "Entrance-Components-Ready",
        dpt = DPT(1, 2),
        rCo = 1102,
        event = true
      },
      {
        name = "Arm-Away-Ready",
        dpt = DPT(1, 2),
        rCo = 1103,
        event = true
      },
      {
        name = "Arm-To-Stay-Ready",
        dpt = DPT(1, 2),
        rCo = 1104,
        event = true
      },
      {
        name = "Burglar-Alarm",
        dpt = DPT(1, 11),
        rCo = 1123,
        event = true
      },
	  {
        name = "Burglar-Alarm-Away-Armed",
        dpt = DPT(1, 11),
        rCo = 1124,
        event = true
      },
	  {
        name = "Burglar-Alarm-Stay-Armed",
        dpt = DPT(1, 11),
        rCo = 1125,
        event = true
      },
      {
        name = "Panic-Alarm",
        dpt = DPT(1, 11),
        rCo = 1131,
        event = true
      },
      {
        name = "Fire-Alarm",
        dpt = DPT(1, 11),
        rCo = 1133,
        event = true
      },
      {
        name = "Vital-Alarm",
        dpt = DPT(1, 11),
        rCo = 1135,
        event = true
      },
      {
        name = "Medical-Alarm",
        dpt = DPT(1, 11),
        rCo = 1137,
        event = true
      },
      {
        name = "Sabotage-Alarm",
        dpt = DPT(1, 11),
        rCo = 1139,
        event = true
      },
      {
        name = "Supervision-Alarm",
        dpt = DPT(1, 11),
        rCo = 1140,
        event = true
      },
      {
        name = "Technical-Alarm",
        dpt = DPT(1, 11),
        rCo = 1142,
        event = true
      },
      {
        name = "Technical-Urgent-Alarm",
        dpt = DPT(1, 11),
        rCo = 1144,
        event = true
      },
      {
        name = "Trouble",
        dpt = DPT(1, 11),
        rCo = 1145,
        event = true
      },
      {
        name = "Chime",
        dpt = DPT(1, 16),
        rCo = 1181,
        event = true
      }
    }
  },
  
  {
    name = "External-Detector-Security-Area-{0}",
    count = 4,
    offset = 100,
    dps = {
      {
        name = "Burglar-Alarm",
        dpt = DPT(1, 1),
        wCo = 1121,
        internal = false
      },
      {
        name = "Burglar-Alarm-Away-Armed",
        dpt = DPT(1, 1),
        wCo = 1122,
        internal = false
      },
      {
        name = "Panic-Alarm",
        dpt = DPT(1, 17),
        wCo = 1130,
        internal = false
      },
      {
        name = "Fire-Alarm",
        dpt = DPT(1, 1),
        wCo = 1132,
        internal = false
      },
      {
        name = "Vitality-Confirmation",
        dpt = DPT(1, 17),
        wCo = 1134,
        internal = false
      },
      {
        name = "Medical-Alarm",
        dpt = DPT(1, 17),
        wCo = 1136,
        internal = false
      },
      {
        name = "Sabotage-Alarm",
        dpt = DPT(1, 1),
        wCo = 1138,
        internal = false
      },
      {
        name = "Technical-Alarm",
        dpt = DPT(1, 1),
        wCo = 1141,
        internal = false
      },
      {
        name = "Technical-Urgent-Alarm",
        dpt = DPT(1, 1),
        wCo = 1143,
        internal = false
      }
    }
  }
}

m.InitUrn(channelTable)

local timeCoTable = {
  {
    dpt = DPT(11, 1),
    rCo = 6
  },
  {
    dpt = DPT(10, 1),
    rCo = 7
  }
}

m.InitTimeCoTable(timeCoTable)


--[[
KNX properties management
]]

-- fix value could disable by set to 0 only
-- see KnxStack::InterfaceObjectType or (own type > 50000 and ID > 50)
local InterfaceObjectId = 0x0003
m.InitInterfaceObjectId(InterfaceObjectId)

-- see KNX specification (for Object type [0..99] the ID > 200)
local PropertyTable = {}
-- row = Property ID, type (KnxStack::PropertyDatatype), name
PropertyTable[1] = {201, 0x02, "TimeMode"} -- PDT_UNSIGNED_CHAR

m.InitPropertyTable(PropertyTable)

--[[
end KNX properties management
]]
